@@ -39,7 +39,7 @@ BoolFieldWidget::BoolFieldWidget(Tellico::Data::FieldPtr field_, QWidget* parent
 
 QString BoolFieldWidget::text() const {
   if(m_checkBox->isChecked()) {
-    return QLatin1String("true");
+    return QStringLiteral("true");
   }
 
   return QString();
